@@ -1,5 +1,5 @@
 /*
-	Author: Marco Costalba (C) 2005-2006
+	Author: Marco Costalba (C) 2005-2007
 
 	Copyright: See COPYING file that comes with this distribution
 
@@ -7,9 +7,9 @@
 #ifndef EXCEPTIONMANAGER_H
 #define EXCEPTIONMANAGER_H
 
-#include <qvaluevector.h>
-#include <qmap.h>
-#include <qstring.h>
+#include <QVector>
+#include <QString>
+#include <QMap>
 
 // exception manager sugar macro
 #define EM_DECLARE(x)    int x
@@ -33,9 +33,9 @@
                                EM_AFTER_PROCESS_EVENTS;  \
                           } while (false)
 
-#define EM_PROCESS_EVENTS_NO_INPUT do { EM_BEFORE_PROCESS_EVENTS;                          \
-                                        qApp->processEvents(QEventLoop::ExcludeUserInput); \
-                                        EM_AFTER_PROCESS_EVENTS;                           \
+#define EM_PROCESS_EVENTS_NO_INPUT do { EM_BEFORE_PROCESS_EVENTS;                                \
+                                        qApp->processEvents(QEventLoop::ExcludeUserInputEvents); \
+                                        EM_AFTER_PROCESS_EVENTS;                                 \
                                    } while (false)
 
 class ExceptionManager { // singleton class
@@ -73,12 +73,12 @@ private:
 		bool verbose;
 		bool isRaised;
 	};
-	typedef QValueList<Exception> ThrowableSet;
+	typedef QList<Exception> ThrowableSet;
 	typedef ThrowableSet::iterator SetIt;
 	QMap<int, ThrowableSet> throwableSetMap;
 	ThrowableSet totalThrowableSet;
 	ThrowableSet regionThrowableSet;
-	QValueVector<QString> descriptions;
+	QVector<QString> descriptions;
 
 	SetIt findExcp(ThrowableSet& ts, const SetIt& startIt, int excpId);
 	void setRaisedFlag(ThrowableSet& ts, int excpId);
