@@ -15,6 +15,7 @@
 #include <QShortcut>
 #include <QDrag>
 #include <QUrl>
+#include <QSettings>
 #include "FileHistory.h"
 #include "domain.h"
 #include "mainimpl.h"
@@ -65,6 +66,10 @@ void ListView::setup(Domain* dm, Git* g) {
 ListView::~ListView() {
 
 	git->cancelDataLoading(fh); // non blocking
+
+	const QString settingsKey = git->isMainHistory(fh) ? QGit::REV_COLS_KEY : QGit::FILE_COLS_KEY;
+	QSettings settings;
+	settings.setValue(settingsKey, header()->saveState());
 }
 
 const QString ListView::sha(int row) const {
@@ -95,22 +100,22 @@ void ListView::setupGeometry() {
 
 	QHeaderView* hv = header();
 	hv->setStretchLastSection(true);
-#if QT_VERSION >= 0x050000
 	hv->setSectionResizeMode(LOG_COL, QHeaderView::Interactive);
 	hv->setSectionResizeMode(TIME_COL, QHeaderView::Interactive);
 	hv->setSectionResizeMode(ANN_ID_COL, QHeaderView::ResizeToContents);
-#else
-	hv->setResizeMode(LOG_COL, QHeaderView::Interactive);
-	hv->setResizeMode(TIME_COL, QHeaderView::Interactive);
-	hv->setResizeMode(ANN_ID_COL, QHeaderView::ResizeToContents);
-#endif
 	hv->resizeSection(GRAPH_COL, DEF_GRAPH_COL_WIDTH);
 	hv->resizeSection(LOG_COL, DEF_LOG_COL_WIDTH);
+	hv->resizeSection(HASH_COL, DEF_HASH_COL_WIDTH);
 	hv->resizeSection(AUTH_COL, DEF_AUTH_COL_WIDTH);
 	hv->resizeSection(TIME_COL, DEF_TIME_COL_WIDTH);
 
 	if (git->isMainHistory(fh))
 		hideColumn(ANN_ID_COL);
+
+	const QString settingsKey = git->isMainHistory(fh) ? QGit::REV_COLS_KEY : QGit::FILE_COLS_KEY;
+	QSettings settings;
+	QVariant v = settings.value(settingsKey);
+	if (v.isValid()) hv->restoreState(v.toByteArray());
 }
 
 void ListView::scrollToNextHighlighted(int direction) {
@@ -210,7 +215,7 @@ void ListView::getSelectedItems(QStringList& selectedItems) {
 	selectedItems = git->sortShaListByIndex(selectedItems);
 }
 
-const QString ListView::shaFromAnnId(uint id) {
+const QString ListView::shaFromAnnId(int id) {
 
 	if (git->isMainHistory(fh))
 		return "";
@@ -348,7 +353,7 @@ QPixmap ListView::pixmapFromSelection(const QStringList &revs, const QString &re
 		QStyleOptionViewItem o(opt);
 		QString dummy;
 		getTagMarkParams(dummy, o, refTypeFromName(ref), false);
-		painter.fillRect(0, 0, fm.width(ref)+2*spacing, height, o.palette.window());
+		painter.fillRect(0, 0, fm.horizontalAdvance(ref)+2*spacing, height, o.palette.window());
 		painter.drawText(spacing, fm.ascent()+1, ref);
 		row = 1;
 	}
@@ -413,7 +418,7 @@ void ListView::startDragging(QMouseEvent* /*e*/) {
 
 void ListView::mouseMoveEvent(QMouseEvent* e) {
 
-	if (e->buttons() == Qt::LeftButton) {
+	if (e->buttons() == Qt::LeftButton && QGit::testFlag(QGit::ENABLE_DRAGNDROP_F)) {
 		startDragging(e);
 		return;
 	}
@@ -487,7 +492,7 @@ void ListView::dragEnterEvent(QDragEnterEvent* e) {
 
 	SCRef revsText(e->mimeData()->data("application/x-qgit-revs"));
 	QString header = revsText.section("\n", 0, 0);
-	dropInfo->shas = revsText.section("\n", 1).split('\n', QString::SkipEmptyParts);
+	dropInfo->shas = revsText.section("\n", 1).split('\n', QGIT_SPLITBEHAVIOR(SkipEmptyParts));
 	// extract refname and sha from first entry again
 	dropInfo->sourceRef = dropInfo->shas.front().section(" ", 1);
 	dropInfo->shas.front() = dropInfo->shas.front().section(" ", 0, 0);
@@ -1065,7 +1070,7 @@ void ListViewDelegate::paintLog(QPainter* p, const QStyleOptionViewItem& opt,
 	QStyleOptionViewItem newOpt(opt); // we need a copy
 	if (pm) {
 		p->drawPixmap(newOpt.rect.x(), newOpt.rect.y() + 1, *pm); // +1 means leave a pixel spacing above the pixmap
-		newOpt.rect.adjust(pm->width() / static_cast<int>(dpr()), 0, 0, 0);
+		newOpt.rect.adjust(static_cast<int>(pm->width() / dpr()), 0, 0, 0);
 		delete pm;
 	}
 	if (isHighlighted)
@@ -1167,11 +1172,7 @@ QString ListView::refNameAt(const QPoint &pos)
  * Return the device pixel ratio
  */
 qreal ListViewDelegate::dpr(void) const {
-#if QT_VERSION >= QT_VERSION_CHECK(5,6,0)
-    return qApp->devicePixelRatio();
-#else
-    return 1.0;
-#endif
+	return qApp->devicePixelRatio();
 }
 
 void ListViewDelegate::addTextPixmap(QPixmap** pp, SCRef txt, const QStyleOptionViewItem& opt) const {
@@ -1179,7 +1180,7 @@ void ListViewDelegate::addTextPixmap(QPixmap** pp, SCRef txt, const QStyleOption
 	QPixmap* pm = *pp;
 
 	const unsigned int mark_spacing = 2; // Space between markers in pixels
-	unsigned int offset = pm->isNull() ? 0 : (pm->width() / static_cast<uint>(dpr())) + mark_spacing; // Marker's offset in the base pixmap
+	unsigned int offset = pm->isNull() ? 0 : static_cast<unsigned int>(pm->width() / dpr()) + mark_spacing; // Marker's offset in the base pixmap
 
 	QFontMetrics fm(opt.font);
 	const unsigned int text_spacing = 4;
@@ -1187,13 +1188,11 @@ void ListViewDelegate::addTextPixmap(QPixmap** pp, SCRef txt, const QStyleOption
 	unsigned int text_height = fm.height();
 
 	// Define size of the new Pixmap
-	QSize pixmapSize((offset + text_width) * static_cast<int>(dpr()),
-			 (text_height) * static_cast<int>(dpr()));
+	QSize pixmapSize(static_cast<int>((offset + text_width) * dpr()),
+			 static_cast<int>(text_height * dpr()));
 
 	QPixmap* newPm = new QPixmap(pixmapSize);
-#if QT_VERSION >= QT_VERSION_CHECK(5,6,0)
-    newPm->setDevicePixelRatio(dpr());
-#endif
+	newPm->setDevicePixelRatio(dpr());
 
 	QPainter p;
 	p.begin(newPm);
