@@ -67,7 +67,7 @@ MainImpl::MainImpl(SCRef cd, QWidget* p) : QMainWindow(p) {
 
 	// create light and dark colors for alternate background
 	ODD_LINE_COL = palette().color(QPalette::Base);
-	EVEN_LINE_COL = ODD_LINE_COL.dark(103);
+	EVEN_LINE_COL = ODD_LINE_COL.darker(103);
 
 	// our interface to git world
 	git = new Git(this);
@@ -87,25 +87,14 @@ MainImpl::MainImpl(SCRef cd, QWidget* p) : QMainWindow(p) {
 	QSettings settings;
 	QString font(settings.value(STD_FNT_KEY).toString());
 	if (font.isEmpty()) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,2,0))
 		font = QFontDatabase::systemFont(QFontDatabase::GeneralFont).toString();
-#else
-		font = QApplication::font().toString();
-#endif
 	}
 	QGit::STD_FONT.fromString(font);
 
 	// set-up typewriter (fixed width) font
 	font = settings.value(TYPWRT_FNT_KEY).toString();
 	if (font.isEmpty()) { // choose a sensible default
-#if (QT_VERSION >= QT_VERSION_CHECK(5,2,0))
 		QFont fnt = QFontDatabase::systemFont(QFontDatabase::FixedFont);
-#else
-		QFont fnt = QApplication::font();
-		fnt.setStyleHint(QFont::TypeWriter, QFont::PreferDefault);
-		fnt.setFixedPitch(true);
-		fnt.setFamily(fnt.defaultFamily()); // the family corresponding
-#endif
 		font = fnt.toString();              // to current style hint
 	}
 	QGit::TYPE_WRITER_FONT.fromString(font);
@@ -204,6 +193,7 @@ MainImpl::MainImpl(SCRef cd, QWidget* p) : QMainWindow(p) {
 
 void MainImpl::initWithEventLoopActive() {
 
+	emit flagChanged(QGit::ENABLE_DRAGNDROP_F);
 	git->checkEnvironment();
 	setRepository(startUpDir);
 	startUpDir = ""; // one shot
@@ -437,7 +427,6 @@ void MainImpl::setRepository(SCRef newDir, bool refresh, bool keepSelection,
 			dbs("ASSERT in setRepository: different dir with no range select");
 
 		// now we can clear all our data
-		setWindowTitle(curDir + " - QGit");
 		bool complete = !refresh || !keepSelection;
 		rv->clear(complete);
 		if (archiveChanged)
@@ -448,20 +437,26 @@ void MainImpl::setRepository(SCRef newDir, bool refresh, bool keepSelection,
 		updateContextActions("", "", false, false);
 		ActCommit_setEnabled(false);
 
-		if (ActFilterTree->isChecked())
-			setWindowTitle(windowTitle() + " - FILTER ON < " +
-			               passedArgs->join(" ") + " >");
-
 		// tree name should be set before init because in case of
 		// StGIT archives the first revs are sent before init returns
 		QString n(curDir);
 		treeView->setTreeName(n.prepend('/').section('/', -1, -1));
 
+		QString curBranch;
+
 		bool quit;
 		bool ok = git->init(curDir, !refresh, passedArgs, overwriteArgs, &quit); // blocking call
 		if (quit)
 			goto exit;
 
+		curBranch = git->getCurrentBranchName();
+		if (curBranch.length()) curBranch = " [" + curBranch + "]";
+		setWindowTitle(curDir + curBranch + " - QGit");
+
+		if (ActFilterTree->isChecked())
+			setWindowTitle(windowTitle() + " - FILTER ON < " +
+					passedArgs->join(" ") + " >");
+
 		updateCommitMenu(ok && git->isStGITStack());
 		ActCheckWorkDir->setChecked(testFlag(DIFF_INDEX_F)); // could be changed in Git::init()
 
@@ -585,9 +580,17 @@ void MainImpl::fileList_itemDoubleClicked(QListWidgetItem* item) {
 	if (isFirst && rv->st.isMerge())
 		return;
 
-	if (testFlag(OPEN_IN_EDITOR_F, FLAGS_KEY)) {
+	QSettings settings;
+	FileDoubleClickAction action_idx = static_cast<FileDoubleClickAction>(
+		settings.value(DCLICK_ACT_KEY, VIEW_PATCH).toUInt());
+
+	if (action_idx == OPEN_IN_EDITOR) {
 		if (item && ActExternalEditor->isEnabled())
 			ActExternalEditor->activate(QAction::Trigger);
+	} else if (action_idx == OPEN_IN_DIFFER) {
+		bool isMainView = (item && item->listWidget() == rv->tab()->fileList);
+		if (isMainView && ActExternalDiff->isEnabled())
+			ActExternalDiff->activate(QAction::Trigger);
 	} else {
 		bool isMainView = (item && item->listWidget() == rv->tab()->fileList);
 		if (isMainView && ActViewDiff->isEnabled())
@@ -599,9 +602,16 @@ void MainImpl::fileList_itemDoubleClicked(QListWidgetItem* item) {
 }
 
 void MainImpl::treeView_doubleClicked(QTreeWidgetItem* item, int) {
-	if (testFlag(OPEN_IN_EDITOR_F, FLAGS_KEY)) {
+	QSettings settings;
+	FileDoubleClickAction action_idx = static_cast<FileDoubleClickAction>(
+		settings.value(DCLICK_ACT_KEY, VIEW_PATCH).toUInt());
+
+	if (action_idx == OPEN_IN_EDITOR) {
 		if (item && ActExternalEditor->isEnabled())
 			ActExternalEditor->activate(QAction::Trigger);
+	} else if (action_idx == OPEN_IN_DIFFER) {
+		if (item && ActExternalDiff->isEnabled())
+			ActExternalDiff->activate(QAction::Trigger);
 	} else {
 		if (item && ActViewFile->isEnabled())
 			ActViewFile->activate(QAction::Trigger);
@@ -706,7 +716,7 @@ bool MainImpl::eventFilter(QObject* obj, QEvent* ev) {
 		if (e->modifiers() == Qt::AltModifier) {
 
 			int idx = tabWdg->currentIndex();
-			if (e->delta() < 0)
+			if (e->angleDelta().y() < 0)
 				idx = (++idx == tabWdg->count() ? 0 : idx);
 			else
 				idx = (--idx < 0 ? tabWdg->count() - 1 : idx);
@@ -993,7 +1003,7 @@ bool MainImpl::event(QEvent* e) {
 		EM_PROCESS_EVENTS;
 		MainExecErrorEvent* me = (MainExecErrorEvent*)e;
 		QString text("An error occurred while executing command:\n\n");
-		text.append(me->command() + "\n\nGit says: \n\n" + me->report());
+		text.append(me->command() + "\n\n" + me->report());
 		QMessageBox::warning(this, "Error - QGit", text);
 		QApplication::restoreOverrideCursor(); }
 		break;
@@ -1137,11 +1147,7 @@ void MainImpl::shortCutActivated() {
 	QShortcut* se = dynamic_cast<QShortcut*>(sender());
 
 	if (se) {
-#if QT_VERSION >= 0x050000
 		const QKeySequence& key = se->key();
-#else
-		const int key = se->key();
-#endif
 
 		if (key == Qt::Key_I) {
 			rv->tab()->listViewLog->on_keyUp();
@@ -1318,7 +1324,7 @@ void MainImpl::doUpdateRecentRepoMenu(SCRef newEntry) {
 static void prepareRefSubmenu(QMenu* menu, const QStringList& refs, const QChar sep = '/') {
 
 	FOREACH_SL (it, refs) {
-		const QStringList& parts(it->split(sep, QString::SkipEmptyParts));
+		const QStringList& parts(it->split(sep, QGIT_SPLITBEHAVIOR(SkipEmptyParts)));
 		QMenu* add_here = menu;
 		FOREACH_SL (pit, parts) {
 			if (pit == parts.end() - 1) break;
@@ -1716,7 +1722,7 @@ void MainImpl::doUpdateCustomActionMenu(const QStringList& list) {
 
 	Actions->addSeparator();
 	FOREACH_SL (it, list)
-		Actions->addAction(*it);
+		Actions->addAction(*it)->setMenuRole(QAction::NoRole);
 }
 
 void MainImpl::customAction_triggered(QAction* act) {
@@ -2163,8 +2169,8 @@ void MainImpl::ActAbout_activated() {
 
 	static const char* aboutMsg =
 	"<p><b>QGit version " PACKAGE_VERSION "</b></p>"
-	"<p>Copyright (c) 2005, 2007, 2008 Marco Costalba<br>"
-	"Copyright (c) 2011-2019 <a href='mailto:tibirna@kde.org'>Cristian Tibirna</a></p>"
+	"<p>Copyright (c) 2005-2008 Marco Costalba<br>"
+	"Copyright (c) 2011-2022 <a href='mailto:tibirna@kde.org'>Cristian Tibirna</a></p>"
 	"<p>Use and redistribute under the terms of the<br>"
 	"<a href=\"http://www.gnu.org/licenses/old-licenses/gpl-2.0.html\">GNU General Public License Version 2</a></p>"
 	"<p>Contributors:<br>"
@@ -2196,12 +2202,17 @@ void MainImpl::ActAbout_activated() {
 	"<nobr>2018 <a href='mailto:asturm@gentoo.org'>Andreas Sturmlechner</a>,</nobr> "
 	"<nobr>2018 <a href='mailto:kde@davidedmundson.co.uk'>David Edmundson</a>,</nobr> "
 	"<nobr>2016-2018 <a href='mailto:rhaschke@techfak.uni-bielefeld.de'>Robert Haschke</a>,</nobr> "
-	"<nobr>2018 <a href='mailto:filipe.rinaldi@gmail.com'>Filipe Rinaldi</a>,</nobr> "
+	"<nobr>2018-2022 <a href='mailto:filipe.rinaldi@gmail.com'>Filipe Rinaldi</a>,</nobr> "
 	"<nobr>2018 <a href='mailto:balbusm@gmail.com'>Mateusz Balbus</a>,</nobr> "
-	"<nobr>2019 <a href='mailto:sebastian@pipping.org'>Sebastian Pipping</a>,</nobr> "
-	"<nobr>2019 <a href='mailto:mvf@gmx.eu'>Matthias von Faber</a>,</nobr> "
-	"<nobr>2019 <a href='mailto:Kevin@tigcc.ticalc.org'>Kevin Kofler</a></nobr> "
-
+	"<nobr>2019-2022 <a href='mailto:sebastian@pipping.org'>Sebastian Pipping</a>,</nobr> "
+	"<nobr>2019-2020 <a href='mailto:mvf@gmx.eu'>Matthias von Faber</a>,</nobr> "
+    "<nobr>2019 <a href='mailto:Kevin@tigcc.ticalc.org'>Kevin Kofler</a>,</nobr> "
+    "<nobr>2020 <a href='mailto:cortexspam-github@yahoo.fr'>Matthieu Muffato</a>,</nobr> "
+    "<nobr>2020 <a href='mailto:brent@mbari.org'>Brent Roman</a>,</nobr> "
+    "<nobr>2020 <a href='mailto:jjm@keelhaul.demon.co.uk'>Jonathan Marten</a>,</nobr> "
+    "<nobr>2020 <a href='mailto:yyc1992@gmail.com'>Yichao Yu</a>,</nobr> "
+    "<nobr>2021 <a href='mailto:wickedsmoke@users.sourceforge.net'>Karl Robillard</a></nobr> "
+    "<nobr>2021 <a href='mailto:vchesn@gmail.com'>Vitaly Chesnokov</a></nobr> "
 	"</p>"
 
 	"<p>This version was compiled against Qt " QT_VERSION_STR "</p>";
