@@ -7,7 +7,7 @@
 
 */
 #include <QApplication>
-#include <QTime>
+#include <QElapsedTimer>
 #include "exceptionmanager.h"
 #include "common.h"
 #include "domain.h"
@@ -49,7 +49,7 @@ bool MyProcess::runSync(SCRef rc, QByteArray* ro, QObject* rcv, SCRef buf) {
 	if (!launchMe(runCmd, buf))
 		return false;
 
-	QTime t;
+	QElapsedTimer t;
 	t.start();
 
 	busy = true; // we have to wait here until we exit
@@ -164,8 +164,12 @@ void MyProcess::on_finished(int exitCode, QProcess::ExitStatus exitStatus) {
 	accError += err;
 
 	isErrorExit =   (exitStatus != QProcess::NormalExit)
-	             || (exitCode != 0 && isWinShell)
+#ifdef Q_OS_WIN32
+	             || (exitCode && isWinShell)
 	             || !accError.isEmpty()
+#else
+	             || (exitCode && !accError.isEmpty())
+#endif
 	             ||  canceling;
 
 	if (!canceling) { // no more noise after cancel
@@ -204,7 +208,7 @@ const QStringList MyProcess::splitArgList(SCRef cmd) {
 	if (!(   cmd.contains(QGit::QUOTE_CHAR)
 	      || cmd.contains("\"")
 	      || cmd.contains("\'")))
-		return cmd.split(' ', QString::SkipEmptyParts);
+		return cmd.split(' ', QGIT_SPLITBEHAVIOR(SkipEmptyParts));
 
 	// we have some work to do...
 	// first find a possible separator
@@ -234,7 +238,7 @@ const QStringList MyProcess::splitArgList(SCRef cmd) {
 
 	// QProcess::setArguments doesn't want quote
 	// delimited arguments, so remove trailing quotes
-	QStringList sl(newCmd.split(sepChar, QString::SkipEmptyParts));
+	QStringList sl(newCmd.split(sepChar, QGIT_SPLITBEHAVIOR(SkipEmptyParts)));
 	QStringList::iterator it(sl.begin());
 	for ( ; it != sl.end(); ++it) {
 		if (((*it).left(1) == "\"" && (*it).right(1) == "\"") ||
