@@ -46,6 +46,8 @@ RevsView::RevsView(MainImpl* mi, Git* g, bool isMain) : Domain(mi, g, isMain) {
 	connect(m(), SIGNAL(flagChanged(uint)),
 	        sb, SLOT(flagChanged(uint)));
 
+	connect(m(), SIGNAL(flagChanged(uint)), SLOT(on_flagChanged(uint)));
+
 	connect(git, SIGNAL(newRevsAdded(const FileHistory*, const QVector<ShaString>&)),
 	        this, SLOT(on_newRevsAdded(const FileHistory*, const QVector<ShaString>&)));
 
@@ -233,6 +235,17 @@ void RevsView::on_updateRevDesc() {
 	tab()->textBrowserDesc->setHtml(d);
 }
 
+void RevsView::on_flagChanged(uint flag) {
+
+	if (flag == QGit::ENABLE_DRAGNDROP_F) {
+		if (QGit::testFlag(QGit::ENABLE_DRAGNDROP_F)) {
+			tab()->listViewLog->setSelectionMode(QAbstractItemView::ExtendedSelection);
+		} else {
+			tab()->listViewLog->setSelectionMode(QAbstractItemView::SingleSelection);
+		}
+	}
+}
+
 bool RevsView::doUpdate(bool force) {
 
 	force = force || m()->lineEditSHA->text().isEmpty();
@@ -309,14 +322,17 @@ void RevsView::updateLineEditSHA(bool clear) {
 		l->setText(""); // clears history
 
 	else if (l->text() != st.sha()) {
+		auto hash = QGit::testFlag(QGit::ENABLE_SHORTREF_F)
+			? st.sha().left(git->shortHashLength())
+			: st.sha();
 
 		if (l->text().isEmpty())
-			l->setText(st.sha()); // first rev clears history
+			l->setText(hash); // first rev clears history
 		else {
 			// setText() clears undo/redo history so
 			// we use clear() + insert() instead
 			l->clear();
-			l->insert(st.sha());
+			l->insert(hash);
 		}
 	}
 	m()->ActBack->setEnabled(l->isUndoAvailable());
